@@ -4,8 +4,11 @@ from dataclasses import dataclass
 from feast.core.CoreService_pb2_grpc import CoreServiceStub
 from feast.core.CoreService_pb2 import (
     ListOnlineStoresRequest,
-    ListOnlineStoresResponse
+    ListOnlineStoresResponse,
+    GetFeatureTableRequest,
+    GetFeatureTableResponse
 )
+from feast.core.FeatureTable_pb2 import FeatureTableSpec
 from feast_spark.api.JobService_pb2 import (
     StartOfflineToOnlineIngestionJobRequest,
     StartOfflineToOnlineIngestionJobResponse
@@ -15,6 +18,7 @@ from feast_spark.api.JobService_pb2_grpc import JobServiceStub
 @dataclass
 class Client:
     registry_url: str
+    project: str = None
     _core_service_stub: CoreServiceStub = None
     _job_service_stub: JobServiceStub = None
 
@@ -50,8 +54,12 @@ class Client:
         return response
 
     def start_offline_to_online_ingestion(
-        self, project: str, feature_table: str, start: datetime, end: datetime, delta_ingestion: bool = False
+        self, feature_table: str, start: datetime, end: datetime, project: str = None, delta_ingestion: bool = False
     ) -> StartOfflineToOnlineIngestionJobResponse:
+
+        if project is None:
+            project = self.project
+
         request = StartOfflineToOnlineIngestionJobRequest(
             project=project, table_name=feature_table, delta_ingestion=delta_ingestion
         )
@@ -62,3 +70,27 @@ class Client:
         except grpc.RpcError:
             raise
         return response
+
+    def get_feature_table(self, name: str, project: str = None) -> FeatureTableSpec:
+        """
+        Retrieves a feature table.
+
+        Args:
+            project: Feast project that this feature table belongs to
+            name: Name of feature table
+
+        Returns:
+            Returns either the requested feature table spec or raises an exception if
+            none is found
+        """
+
+        if project is None:
+            project = self.project
+
+        try:
+            response = self._core_service.GetFeatureTable(
+                GetFeatureTableRequest(project=project, name=name.strip()),
+            )
+        except grpc.RpcError:
+            raise
+        return response.table.spec
